@@ -67,7 +67,6 @@ def deviationFunction(x):
     return [y]
 
 model_py = ot.PythonFunction(4, 1, deviationFunction)
-model_py.enableHistory()
 
 #§ FMU model
 import otfmi
@@ -93,14 +92,13 @@ except FMUException:
                        " available on your platform (%s)." %
                        "-".join(key_platform))
     sys.exit()
-model_fmu.enableHistory()
 
 def create_monte_carlo(model, inputRandomVector, coefficient_variation):
     """Create a Monte Carlo algorithm.
 
     Parameters
     ----------
-    model : OpenTURNS NumericalMathFunction.
+    model : OpenTURNS Function.
 
     inputRandomVector : OpenTURNS RandomVector, vector of random inputs.
 
@@ -127,7 +125,7 @@ def run_monte_carlo(model, coefficient_variation=0.20):
 
     Parameters
     ----------
-    model : OpenTURNS NumericalMathFunction.
+    model : OpenTURNS Function.
 
     coefficient_variation : Float, target for the coefficient of variation of
     the estimator.
